import { v4 as uuidv4 } from "uuid"
import type { Simulation } from "./debutant"

const intermediaireSimulations: Simulation[] = [
  {
    id: uuidv4(),
    title: "Simulation intermédiaire #1",
    description: "Première simulation pour les conducteurs de niveau intermédiaire",
    duration: 25,
    questions: [
      {
        id: uuidv4(),
        question: "Dans quelle situation le freinage d'urgence est-il recommandé ?",
        options: [
          "À l'approche d'un feu rouge",
          "Pour éviter un obstacle imprévu",
          "Pour céder le passage",
          "Pour ralentir sur autoroute",
        ],
        correctAnswer: "Pour éviter un obstacle imprévu",
        explanation:
          "Le freinage d'urgence est recommandé uniquement en cas de danger imminent, comme pour éviter un obstacle imprévu. Dans les autres situations, un freinage progressif est préférable.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la distance d'arrêt à 90 km/h sur route sèche ?",
        options: ["Environ 25 mètres", "Environ 50 mètres", "Environ 80 mètres", "Environ 120 mètres"],
        correctAnswer: "Environ 80 mètres",
        explanation:
          "À 90 km/h, la distance d'arrêt est d'environ 80 mètres sur route sèche (25 mètres de distance de réaction + 55 mètres de distance de freinage).",
      },
      {
        id: uuidv4(),
        question: "Que signifie un panneau rond à fond bleu ?",
        options: ["Une interdiction", "Une obligation", "Une indication", "Un danger"],
        correctAnswer: "Une obligation",
        explanation:
          "Les panneaux ronds à fond bleu sont des panneaux d'obligation qui indiquent un comportement obligatoire à adopter (direction obligatoire, vitesse minimale, etc.).",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation du téléphone au volant ?",
        options: [
          "Autorisée avec une oreillette",
          "Autorisée avec un kit mains libres",
          "Interdite dans tous les cas",
          "Autorisée à l'arrêt moteur allumé",
        ],
        correctAnswer: "Interdite dans tous les cas",
        explanation:
          "L'utilisation du téléphone tenu en main est strictement interdite au volant. Même avec un kit mains libres, l'usage du téléphone reste dangereux car il diminue l'attention du conducteur.",
      },
      {
        id: uuidv4(),
        question: "Quand faut-il allumer les feux de croisement en journée ?",
        options: ["Par temps de pluie", "Sur autoroute uniquement", "En ville uniquement", "Uniquement la nuit"],
        correctAnswer: "Par temps de pluie",
        explanation:
          "Les feux de croisement doivent être allumés par temps de pluie, mais aussi en cas de brouillard, de chute de neige, ou lorsque la visibilité est réduite.",
      },
    ],
  },
  {
    id: uuidv4(),
    title: "Simulation intermédiaire #2",
    description: "Deuxième simulation pour les conducteurs de niveau intermédiaire",
    duration: 25,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la règle pour dépasser un cycliste en agglomération ?",
        options: [
          "Laisser 0,5 mètre d'écart latéral",
          "Laisser 1 mètre d'écart latéral",
          "Laisser 1,5 mètre d'écart latéral",
          "Attendre d'être sur une autre voie",
        ],
        correctAnswer: "Laisser 1 mètre d'écart latéral",
        explanation:
          "En agglomération, il faut laisser un écart latéral d'au moins 1 mètre pour dépasser un cycliste. Hors agglomération, cet écart doit être d'au moins 1,5 mètre.",
      },
      {
        id: uuidv4(),
        question: "Quand peut-on utiliser son avertisseur sonore en agglomération ?",
        options: [
          "Pour saluer un ami",
          "En cas de danger immédiat uniquement",
          "Pour signaler sa présence",
          "Pour manifester son mécontentement",
        ],
        correctAnswer: "En cas de danger immédiat uniquement",
        explanation:
          "En agglomération, l'usage de l'avertisseur sonore n'est autorisé qu'en cas de danger immédiat. Hors agglomération, il peut également être utilisé pour signaler sa présence.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la durée maximale de conduite continue recommandée avant une pause ?",
        options: ["1 heure", "2 heures", "3 heures", "4 heures"],
        correctAnswer: "2 heures",
        explanation:
          "Il est recommandé de faire une pause d'au moins 15 minutes toutes les 2 heures de conduite pour maintenir sa vigilance et éviter la fatigue au volant.",
      },
      {
        id: uuidv4(),
        question: "Quel est le délai pour changer d'adresse sur la carte grise après un déménagement ?",
        options: ["15 jours", "1 mois", "3 mois", "6 mois"],
        correctAnswer: "1 mois",
        explanation:
          "Après un changement d'adresse, vous disposez d'un délai d'un mois pour faire modifier l'adresse sur votre certificat d'immatriculation (carte grise).",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le stationnement sur les trottoirs ?",
        options: [
          "Autorisé si le véhicule ne gêne pas les piétons",
          "Autorisé uniquement pour les deux-roues",
          "Interdit sauf indication contraire",
          "Autorisé la nuit uniquement",
        ],
        correctAnswer: "Interdit sauf indication contraire",
        explanation:
          "Le stationnement sur les trottoirs est interdit, sauf indication contraire matérialisée par un marquage au sol ou une signalisation spécifique.",
      },
    ],
  },
]

export default intermediaireSimulations
